==> icons-vue-0.6.0.tgz: package/lib/calculator/32.js <==
'use strict';

var _rollupPluginBabelHelpers = require('../_rollupPluginBabelHelpers-00d81fcb.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_Calculator32 = {
  name: 'Calculator32',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(_rollupPluginBabelHelpers._objectSpread2({
      width: '32',
      height: '32',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _rollupPluginBabelHelpers._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _rollupPluginBabelHelpers._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M26,4V28H6V4H26m0-2H6A2,2,0,0,0,4,4V28a2,2,0,0,0,2,2H26a2,2,0,0,0,2-2V4A2,2,0,0,0,26,2Z"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "9",
        "y": "23"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "21",
        "y": "23"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "9",
        "y": "18"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "21",
        "y": "18"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "9",
        "y": "13"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "15",
        "y": "23"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "15",
        "y": "18"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "15",
        "y": "13"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "2",
        "x": "21",
        "y": "13"
      }
    }), createElement('rect', {
      attrs: {
        "width": "14",
        "height": "3",
        "x": "9",
        "y": "7"
      }
    }), children]);
  }
};

module.exports = virtual_Calculator32;

==> icons-vue-10.6.1.tgz: package/lib/calculator/32.js <==
'use strict';

var __chunk_1 = require('../chunk-d2faeea1.js');
var iconHelpers = require('@carbon/icon-helpers');

var virtual_Calculator32 = {
  name: 'Calculator32',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(__chunk_1._objectSpread2({
      width: '32',
      height: '32',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = __chunk_1._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M26 4v24H6V4h20m0-2H6a2 2 0 0 0-2 2v24a2 2 0 0 0 2 2h20a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M9 23h2v2H9zm12 0h2v2h-2zM9 18h2v2H9zm12 0h2v2h-2zM9 13h2v2H9zm6 10h2v2h-2zm0-5h2v2h-2zm0-5h2v2h-2zm6 0h2v2h-2zM9 7h14v3H9z"
      }
    }), children]);
  }
};

module.exports = virtual_Calculator32;
